package main

import (
	"database/sql"
	"flag"
	"log"
	"os"

	"git.katuwoss.dev/JustScreaMy/secret-santa/internal/app"
	"git.katuwoss.dev/JustScreaMy/secret-santa/internal/config"
	_ "github.com/go-sql-driver/mysql"
	_ "github.com/jackc/pgx/v5/stdlib"
	_ "github.com/mattn/go-sqlite3"
)

var (
	configPath string
)

func init() {
	flag.StringVar(&configPath, "config", "config.yaml", "path to config file")
	flag.Parse()

	// Check if the config file exists
	if _, err := os.Stat(configPath); os.IsNotExist(err) {
		log.Fatalf("Config file not found: %s", configPath)
	}
	log.Printf("Using config file: %s", configPath)
}

func main() {
	appConfig, err := config.ParseConfig(configPath)
	if err != nil {
		log.Fatalf("Failed to parse config: %s", err.Error())
	}

	dbConnection, err := sql.Open(appConfig.DB.GetDriver(), appConfig.DB.GenerateDSN())

	if err != nil {
		log.Fatalf("Database connection failed: %s", err.Error())
	}

	if dbConnection.Ping() != nil {
		log.Fatalf("Database connection failed: unable to ping database")
	}

	log.Println("Database sucessfully connected")
	application := app.NewApp(dbConnection, &appConfig.App, nil)

	log.Printf("Listening on http://%s", appConfig.App.GenerateIP())
	log.Fatal(application.Start())
}
